Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4490)

Unified Diff: chrome/browser/ui/views/uninstall_view.cc

Issue 12342026: Fix GetDialogButtonLabel for UninstallView. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/uninstall_view.cc
diff --git a/chrome/browser/ui/views/uninstall_view.cc b/chrome/browser/ui/views/uninstall_view.cc
index e15118e0f2462452573e8371005a6e26d631dab1..a3fc778bc80803c901b964e065fa9d7dedf33a6b 100644
--- a/chrome/browser/ui/views/uninstall_view.cc
+++ b/chrome/browser/ui/views/uninstall_view.cc
@@ -129,11 +129,10 @@ bool UninstallView::Cancel() {
}
string16 UninstallView::GetDialogButtonLabel(ui::DialogButton button) const {
// We only want to give custom name to OK button - 'Uninstall'. Cancel
// button remains same.
if (button == ui::DIALOG_BUTTON_OK)
return l10n_util::GetStringUTF16(IDS_UNINSTALL_BUTTON_TEXT);
- return string16();
+ return views::DialogDelegateView::GetDialogButtonLabel(button);
}
void UninstallView::ButtonPressed(views::Button* sender,
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -129,11 +129,10 @@ bool UninstallView::Cancel() {
}
string16 UninstallView::GetDialogButtonLabel(ui::DialogButton button) const {
- // We only want to give custom name to OK button - 'Uninstall'. Cancel
- // button remains same.
+ // Label the OK button 'Uninstall'; Cancel remains the same.
if (button == ui::DIALOG_BUTTON_OK)
return l10n_util::GetStringUTF16(IDS_UNINSTALL_BUTTON_TEXT);

Powered by Google App Engine
This is Rietveld 408576698